==> jetspeed-2-2.2.2-source-release.zip: jetspeed-2-2.2.2/jetspeed-api/src/main/java/org/apache/jetspeed/administration/RegistrationException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.jetspeed.administration;

import org.apache.jetspeed.exception.JetspeedException;
import org.apache.jetspeed.i18n.KeyedMessage;

/**
 * Registration-related exceptions
 * 
 * @author <a href="mailto:taylor@apache.org">David Sean Taylor</a>
 * @version $Id: $
 */
public class RegistrationException extends JetspeedException
{
    public RegistrationException()
    {
        super();
    }

    public RegistrationException(KeyedMessage keyedMessage, Throwable nested)
    {
        super(keyedMessage, nested);
    }

    public RegistrationException(KeyedMessage typedMessage)
    {
        super(typedMessage);
    }

    public RegistrationException(String msg, Throwable nested)
    {
        super(msg, nested);
    }

    public RegistrationException(String message)
    {
        super(message);
    }

    public RegistrationException(Throwable nested)
    {
        super(nested);
    }
}

==> jetspeed-2-2.3.1-source-release.zip: jetspeed-2-2.3.1/jetspeed-api/src/main/java/org/apache/jetspeed/administration/RegistrationException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.jetspeed.administration;

import org.apache.jetspeed.exception.JetspeedException;
import org.apache.jetspeed.i18n.KeyedMessage;

/**
 * Portal Administration Registration-related exceptions
 * 
 * @author <a href="mailto:taylor@apache.org">David Sean Taylor</a>
 * @version $Id: $
 */
public class RegistrationException extends JetspeedException
{
    public RegistrationException()
    {
        super();
    }

    public RegistrationException(KeyedMessage keyedMessage, Throwable nested)
    {
        super(keyedMessage, nested);
    }

    public RegistrationException(KeyedMessage typedMessage)
    {
        super(typedMessage);
    }

    public RegistrationException(String msg, Throwable nested)
    {
        super(msg, nested);
    }

    public RegistrationException(String message)
    {
        super(message);
    }

    public RegistrationException(Throwable nested)
    {
        super(nested);
    }
}
